<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: class.Linux.inc.php,v 1.1 2001/12/31 23:54:31 precision Exp $
//

class sysinfo
{
    // get our apache SERVER_NAME or vhost
    function vhostname ()
    {
        if (! ($result = getenv('SERVER_NAME'))) {
            $result = 'Unknown Hostname.';
        }
        return $result;
    }

    // get our canonical hostname
    function chostname ()
    {
        if ($fp = fopen('/proc/sys/kernel/hostname','r')) {
            $result = trim(fgets($fp, 4096));
            fclose($fp);
            $result = gethostbyaddr(gethostbyname($result));
        } else {
            $result = $this->vhostname();
        }
        return $result;
    }

    // get the IP address of our canonical hostname
    function ip_addr ()
    {
        if (!($result = getenv('SERVER_ADDR'))) {
            $result = gethostbyname($this->chostname());
        }
        return $result;
    }

    function kernel ()
    {
        $result = trim(execute_program('ver'));
        return $result;
    }

    function uptime ()
    {
        global $text;
        $uptimeAnswer = split(' ', execute_program('uptime'));

        $days = $uptimeAnswer[3];
        list($hours, $min, $secs) = split(":", trim($uptimeAnswer[5], ","));

        if ($days != 0) {
            $result = trim($days, '0') .$text['days']." ";
        }

        if ($hours != 0) {
            $result .= "$hours ".$text['hours']." ";
        }
        $result .= trim($min, "0") . " "  .$text['minutes'];

        return $result;
    }

    function users ()
    {
//        $who = split('=', execute_program('who', '-q'));
//        $result = $who[1];
        return 'N.A.';
    }

    function loadavg ()
    {
//        if ($fd = fopen('/proc/loadavg', 'r')) {
//            $results = split(' ', fgets($fd, 4096));
//            fclose($fd);
//        } else {
            $results = array('N.A.','N.A.','N.A.');
//        }
        return $results;
    }

    function cpu_info ()
    {
        $results = array();
        $ar_buf  = array();
        $cpuid   = split("\n", execute_program('cpuid3b'));

        $results['model'] = substr($cpuid[0], 19);
//        $results['mhz'] = sprintf('%.2f', $value);
        $ar_buf = preg_split("/\s+/", $cpuid[3]);
        $results['cache'] = $ar_buf[0];
//        $results['bogomips'] = 'N.A';
        $results['cpus'] = 'At Least One';

        $keys = compat_array_keys($results);
        $keys2be = array('model', 'mhz', 'cache', 'bogomips', 'cpus');
        $keys2be = array('model', 'mhz', 'cache', 'cpus');

        while ($ar_buf = each($keys2be)) {
            if (! compat_in_array($ar_buf[1], $keys)) {
                $results[$ar_buf[1]] = 'N.A.';
            }
        }
        return $results;

    }

    function pci ()
    {
        $results = array();
        $cpuid   = split("\n", execute_program('cpuid3b'));
        $pciStart = "/^This system has/";
        for ($i = 1; ($i < sizeof($cpuid)) && !preg_match($pciStart, $cpuid[$i]); $i++) {
        }
        $i++;
        for ($j = 0; ($j + $i) < sizeof($cpuid); $j++) {
            $results[$j] = $cpuid[$i + $j];
        }
        return $results;
    }

    function DANIide ()
    {
        $results = array();

        // Check if device is CD-ROM (CD-ROM capacity shows as 1024 GB)
        if ($fd = fopen("IBMS506$", 'r')) {
            while ($buf = trim(fgets($fd, 1024))) {
                if (preg_match('/Model:/', $buf)) {
                    $ar_buf = split(':', $buf);
                    $ar_buf1 = split(' ', $ar_buf[1]);
                    if ($results[$file]['media'] == 'disk') {
                        $results[$file]['media'] = 'Hard Disk';
                    }

                    if ($results[$file]['media'] == 'cdrom') {
                        $results[$file]['media'] = 'CD-ROM';
                    }
                }
            }

            fclose($fd);
         }

        return $results;
    }

    function ide ()
    {
        $results = array();
        $rmview = execute_program('rmview');
        $lines = split("\n", $rmview);

        for ($i = 1; ($i < sizeof($lines)) && !preg_match('/Adapter: IDE/', $lines[$i]); $i++) {
        }
        if ($i < sizeof($lines)) {
           for ($j = $i - 1; $j < sizeof($lines); $j++) {
               if (preg_match('/Adapter: IDE/', $lines[$j])) {
                  $ar_buf = preg_split("/\s+/", trim($lines[$j]), -1, PREG_SPLIT_NO_EMPTY);
                  $ideAdapter = $ar_buf[1];
               }
               if (preg_match('/Device:/', $lines[$j])) {
                  $ar_buf = preg_split("/\s+/", trim($lines[$j]), -1, PREG_SPLIT_NO_EMPTY);
                  $ideDevice = $ideAdapter . '/' . $ar_buf[1];
                  if ($ar_buf[sizeof($ar_buf) - 1] == DISK) {
                     $results[$ideDevice]['media'] = 'Hard Disk';
//                     $results[$ideDevice]['model'] = $ar_buf[2];
                  }
                  if ($ar_buf[sizeof($ar_buf) - 1] == CDROM) {
                     $results[$ideDevice]['media'] = 'CD-ROM';
//                     $results[$ideDevice]['model'] = $ar_buf[2] . ' ' . $ar_buf[3];
                  }
//                  $results[$ideDevice]['capacity'] = $ar_buf[2] * 2048 * 1.049;
                  for ($k = 2; $k < sizeof($ar_buf) - 2; $k++) {
                     $results[$ideDevice]['model'] .= $ar_buf[$k];
                     $results[$ideDevice]['model'] .= ' ';
                  }
               }
           }
        }

        return $results;
    }

    function scsi ()
    {
        $results = array();
        $rmview = execute_program('rmview');
        $lines = split("\n", $rmview);
//        $lines = file("scsi.log");

        $scsiDevices = false;
        $k = 0;
        for ($i = 1; ($i < sizeof($lines)); $i++) {
           if (preg_match('/Device Type: MS-SCSI/', $lines[$i])) {
              $scsiDevices = true;
           }
           else if (preg_match('/Adapter:/', $lines[$i])) {
              $scsiDevices = false;
           }
           if ($scsiDevices) {

               if (preg_match('/Device:/', $lines[$i])) {
                  $ar_buf = preg_split("/\s+/", trim($lines[$i]), -1, PREG_SPLIT_NO_EMPTY);

                  $maxStrings = sizeof($ar_buf);
                  if ($ar_buf[$maxStrings - 1] == 'DISK') {
                     $maxStrings = $maxStrings - 2;
                  }

                  $results[$k] .= $ar_buf[1] . ':';
                  for ($j = 2;
                       ($j < $maxStrings) && (strcmp($ar_buf[$j + 1], 'REMOVABLE') <> 0) && (strcmp($ar_buf[$j + 1], 'PROCESSOR') <> 0)  ;
                       $j++) {
                     $results[$k] .= ' ';
                     $results[$k] .= $ar_buf[$j];
                  }
                  ++$k;
               }
           }
        }
        return $results;
    }

    function memory ()
    {
        $memory = preg_split('/\s+/', execute_program('countmem'));
        $results['ram'] = array();
        $results['ram']['total']   = $memory[4] * 1024;

        $usedMemory = preg_split('/\s+/', execute_program('phpSysInfo.cmd', 'RAM'));
        $results['ram']['free']    = $usedMemory[0] / 1024;
        $results['ram']['used']    = $results['ram']['total'] - $results['ram']['free'];
//      $results['ram']['shared']  = $ar_buf[3] / 1024;
        $results['ram']['buffers'] = 0;
        $results['ram']['cached']  = 0;

        $results['ram']['t_used']  = $results['ram']['used'] - $results['ram']['cached'] - $results['ram']['buffers'];
        $results['ram']['t_used']  = $results['ram']['used'];
        $results['ram']['t_free']  = $results['ram']['total'] - $results['ram']['t_used'];
        $results['ram']['percent'] = round(($results['ram']['t_used'] * 100) / $results['ram']['total']);

        $swapMemory = execute_program('phpSysInfo.cmd', 'SWAP');
        $swapMemory = preg_split('/\s+/', $swapMemory);
        $results['swap'] = array();

        $results['swap']['used']    = $swapMemory[0] * 4;
        $results['swap']['free']    = $swapMemory[1] * 4;
        $results['swap']['total']   = $results['swap']['used'] + $results['swap']['free'];
        $results['swap']['percent'] = round(($results['swap']['used'] * 100) / $results['swap']['total']);

        $swapFile = execute_program('phpSysInfo.cmd', 'SWAPFILE');
        $swapFile = preg_split('/\s+/', $swapFile);
        $results['devswap'][0] = array();
        $results['devswap'][0]['dev']     = 'SWAPPER.DAT';
        $results['devswap'][0]['used']    = $swapFile[0];
        $results['devswap'][0]['free']    = $swapFile[1];
        $results['devswap'][0]['total']   = $results['swap']['used'] + $results['swap']['free'];
        $results['devswap'][0]['percent'] = round(($results['swap']['free'] * 100) / $results['swap']['total']);

        return $results;
    }

    function filesystems ()
    {
        $df = execute_program('phpSysInfo.cmd', 'DISK');
        $mounts = split("\n", $df);
        $fstype = array();

        for ($i = 2; $i < sizeof($mounts); $i++) {
            $ar_buf = preg_split('/\s+/', $mounts[$i], -1, PREG_SPLIT_NO_EMPTY);

            $results[$i - 2] = array();

            $results[$i - 2]['size'] = $ar_buf[1];
            $results[$i - 2]['used'] = $ar_buf[2];
            $results[$i - 2]['free'] = $ar_buf[3];
            $results[$i - 2]['percent'] = round(($results[$i - 2]['used'] * 100) / $results[$i - 2]['size']) . '%';
            $results[$i - 2]['mount']   = $ar_buf[0];

            if (sizeof($ar_buf) == 7) {
               $results[$i - 2]['fstype']  = $ar_buf[6];
            }
            else {
               $results[$i - 2]['fstype']  = $ar_buf[sizeof($ar_buf) - 1];
               for ($j = 6; $j < sizeof($ar_buf) - 1; $j++) {
                  $results[$i - 2]['disk'] .= $ar_buf[$j] . ' ';
               }
            }
        }
        return $results;
    }

    function filesystemsGNU ()
    {
        $df = execute_program('df', '-kP');
        $mounts = split("\n", $df);
        $fstype = array();

        if ($fd = fopen('/proc/mounts', 'r')) {
            while ($buf = fgets($fd, 4096)) {
                list($dev, $mpoint, $type) = preg_split('/\s+/', trim($buf), 4);
                $fstype[$mpoint] = $type;
                $fsdev[$dev] = $type;
            }
            fclose($fd);
        }

        for ($i = 1; $i < sizeof($mounts); $i++) {
            $ar_buf = preg_split('/\s+/', $mounts[$i], 6);

            $results[$i - 1] = array();

            $results[$i - 1]['disk'] = $ar_buf[0];
            $results[$i - 1]['size'] = $ar_buf[1];
            $results[$i - 1]['used'] = $ar_buf[2];
            $results[$i - 1]['free'] = $ar_buf[3];
            $results[$i - 1]['percent'] = round(($results[$i - 1]['used'] * 100) / $results[$i - 1]['size']) . '%';
            $results[$i - 1]['mount'] = $ar_buf[5];
            ($fstype[$ar_buf[5]]) ? $results[$i - 1]['fstype'] = $fstype[$ar_buf[5]] : $results[$i - 1]['fstype'] = $fsdev[$ar_buf[0]];
        }
        return $results;
    }

    function network ()
    {
        $netstat = execute_program('RxNetstat.cmd');
        $lines = split("\n", $netstat);
        $results = array();
        for ($i = 0; $i < sizeof($lines); $i++) {
            $ar_buf = preg_split("/\s+/", $lines[$i]);

            $interface = $ar_buf[0] . ' ' . $ar_buf[18];
            $results[$interface] = array();
            $results[$interface]['rx_bytes']   =  $ar_buf[7];
            $results[$interface]['tx_bytes']   =  $ar_buf[8];
            $results[$interface]['tx_drop']    =  $ar_buf[9];
            $results[$interface]['drop']       += $ar_buf[9];
            $results[$interface]['rx_drop']    =  $ar_buf[10];
            $results[$interface]['drop']       += $ar_buf[10];
            $results[$interface]['rx_errs']    =  $ar_buf[11];
            $results[$interface]['errs']       += $ar_buf[11];
            $results[$interface]['tx_errs']    =  $ar_buf[12];
            $results[$interface]['errs']       += $ar_buf[12];
            $results[$interface]['rx_packets'] += $ar_buf[14];
        }
        return $results;
    }

    // Return an array of information about
    // about network connections
    // Note: Based on version for FreeBSD
    function networkNetstat ()
    {
        $netstat = execute_program('phpSysInfo.cmd', 'NETWORK');
        $lines = split("\n", $netstat);
        $results = array();
        for ($i = 0; $i < sizeof($lines); $i++) {
            $ar_buf = preg_split("/\s+/", $lines[$i]);
            if ($ar_buf[0] == 'Interface') {
                $interface = substr($lines[$i], 9);
                $results[$interface] = array();
            }
            if (stristr($lines[$i], 'total bytes received')) {
                $results[$interface]['rx_bytes'] = $ar_buf[3];
            }
            else if (stristr($lines[$i], 'total bytes sent')) {
                $results[$interface]['tx_bytes'] = $ar_buf[3];
            }
            else if (stristr($lines[$i], 'packets discarded on transmission')) {
                $results[$interface]['tx_drop'] = $ar_buf[4];
                $results[$interface]['drop']    += $ar_buf[4];
            }
            else if (stristr($lines[$i], 'packets discarded on reception')) {
                $results[$interface]['rx_drop'] =  $ar_buf[4];
                $results[$interface]['drop']    += $ar_buf[4];
            }
            else if (stristr($lines[$i], 'received packets in error')) {
                $results[$interface]['rx_errs'] = $ar_buf[4];
                $results[$interface]['errs']    += $ar_buf[4];
            }
            else if (stristr($lines[$i], 'errors trying to send')) {
                $results[$interface]['tx_errs'] = $ar_buf[4];
                $results[$interface]['errs']    += $ar_buf[4];
            }
            else if (stristr($lines[$i], 'unicast packets received')) {
                $results[$interface]['rx_packets'] += $ar_buf[4];
            }
        }
        return $results;
    }
}       // End of class
