/*============================================================================*/
/* phpSysInfo.CMD                                                             */
/*                                                                            */
/* Retrieve information for phpSysInfo.                                       */
/*                                                                            */
/* Calls Rexx utility functions or commands to to retrieve details of the     */
/* OS/2 system.  This is then written out for phpSysInfo to read.             */
/*                                                                            */
/*============================================================================*/
/* Requires:                                                                  */
/*   - Thesues1.DLL from Theseus4                                             */
/* Requires:                                                                  */
/*============================================================================*/
/* Part of phpSysInfo/2                                                       */
/*                                                                            */
/* Copyright David Forrester 2002                                             */
/* Created:  12/03/2002                                                       */
/*                                                                            */
/*============================================================================*/
/* Modification History:                                                      */
/* 0.2.0 - Created with RAM. Swapper, Network and Disk info.                  */
/*                                                                            */
/*============================================================================*/

Trace 'Off'
Parse Upper Arg infoType
infoType = Strip(infoType)

/* Check the parameters. Doesn't really do anything at the moment. */
Select
   When infoType = 'RAM'      Then NOP
   When infoType = 'SWAP'     Then NOP
   When infoType = 'SWAPFILE' Then NOP
   When infoType = 'NETWORK'  Then NOP
   When infoType = 'DISK'     Then NOP
   Otherwise
      infoType = ''
End /* Select */

/* Now get the info required. */
Select
   When infoType = 'RAM'     Then Do
      Call LoadTheseusFuncs
      freeMemoryReturn = RT2FreeMemory()
      Say freeMemoryReturn
   End /* When .. Then Do */

   When infoType = 'SWAP'    Then Do
      Call LoadTheseusFuncs
      freeMemoryReturn = RT2AnalyzeSwapper()
      Say freeMemoryReturn
   End /* When .. Then Do */

   When infoType = 'SWAPFILE' Then Do
      Call LoadRxFuncs
      Call SwapFileSize
   End /* When .. Then Do */

   When infoType = 'NETWORK' Then Do
      Call LoadTCPFuncs
      list = TCPQueryAvailableInterfaces()
      do i = 1 for words(list)
         Say TcpQueryInterface(word(list,i))
      End /* Do .. For .. */
   End /* When .. Then Do */

   When infoType = 'DISK'    Then Do
      Call LoadRxFuncs
      driveMap = SysDriveMap()
      checkedDriveMap = ''
      Do i = 1 to Words(driveMap)
         If Strip(SysDriveInfo(Word(driveMap, i))) <> '' Then checkedDriveMap = checkedDriveMap Word(driveMap, i)
      End
      'df' checkedDriveMap
   End /* When .. Then Do */

   Otherwise
      NOP
End /* Select */

EXIT

SwapFileSize:
   bootDrive = SysBootDrive()
   /* gets swap file path (scans config.sys for SWAPPATH statements */
   If 0 \= SysFileSearch("SWAPPATH", bootDrive || "\CONFIG.SYS", "statement") then do
      Say 0 0
      Exit
   End /* do */
   /* discards invalid statements (comments) */
   do i = 1 to statement.0
      if "SWAPPATH" = left(statement.i, 8) then do
         parse var statement.i "=" swappath minfree initsize
         leave
      end /* do */
   end /* do */

  if right(swappath, 1) = "\" then
     swappath = swappath || "SWAPPER.DAT"
  else
     swappath = swappath || "\SWAPPER.DAT"
   call SysFileTree swappath, "file", "F";
   parse var file.1 . . size . ;
   ffsize = size / 1024;
   Say ffsize 1028160
Return


/* Utitlity functions to load the Rexx libraries. */
LoadRxFuncs:

If RxFuncQuery('SysLoadFuncs') then do
   Call RxFuncAdd 'SysLoadFuncs', 'RexxUtil', 'SysLoadFuncs'
   Call SysLoadFuncs
End /* If .. Then Do */

Return

LoadTheseusFuncs:
/* Loading these each time they get used as otherwise they don't work! */

call RxFuncAdd 'RT2LoadFuncs', 'THESEUS0', 'RT2LoadFuncs'
rc = RT2LoadFuncs()
If rc \= 0 THEN Say 'RT2loadfuncs rc is = 'rc

call RxFuncAdd 'RT2LoadFuncs1', 'THESEUS1', 'RT2LoadFuncs1'
rc = RT2LoadFuncs1()
If rc \= 0 THEN Say 'RT2loadfuncs1 rc is = 'rc

Return


LoadTCPFuncs:

If RxFuncQuery('TcpLoadFuncs') then do
  call RxFuncAdd 'TcpLoadFuncs','RxTCPMon','TcpLoadFuncs'
  call TcpLoadFuncs
End /* If .. Then Do */

Return
